from setuptools import setup, find_packages

setup(
    name="ray-launcher",
    version="1.0.1",
    description="An out-of-the-box ray cluster launcher",
    author="0-1CxH",
    author_email="h0.1c@foxmail.com",
    url="https://github.com/0-1CxH/ray-launcher",
    packages=find_packages(include=[
        "ray_launcher"
    ], exclude=[
        'setup.py', 'test.py'
    ]),
    include_package_data=False,
    install_requires=[
        "ray",
        "loguru"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    license = "MIT Licence",
)


import os
import time
from ray_launcher import ClusterLauncher

os.environ["RAY_DISABLE_DOCKER_CPU_WARNING"] = "1"
os.environ["RAY_memory_monitor_refresh_ms"] = "0"
os.environ["RAY_DEDUP_LOGS"] = "0"

with ClusterLauncher(
    cluster_nodes_count=int(os.environ["NNODES"]),
    head_node_addr=os.environ["MASTER_ADDR"],
    export_env_var_names=["RAY_DISABLE_DOCKER_CPU_WARNING"]
) as launcher:
    print("cluster ready")
    assert launcher.is_head_node, f"only head node reaches here"
    time.sleep(15)
    print("prepare to stop the cluster")